@@ -1,21 +1,20 @@
-use crate::{text_output::TextOutput, TextSubstr, WriteText};
-use layered_io::{Bufferable, LayeredWriter, WriteLayered};
-use std::{
-    fmt::{self, Debug, Formatter},
-    io::{self, Write},
-    str,
-};
-#[cfg(feature = "terminal-io")]
-use terminal_io::{Terminal, TerminalColorSupport, WriteTerminal};
+use crate::text_output::TextOutput;
+use crate::{TextSubstr, WriteText};
 #[cfg(windows)]
-use unsafe_io::os::windows::{
+use io_extras::os::windows::{
     AsHandleOrSocket, AsRawHandleOrSocket, BorrowedHandleOrSocket, RawHandleOrSocket,
 };
+use layered_io::{Bufferable, LayeredWriter, WriteLayered};
+use std::fmt::{self, Debug, Formatter};
+use std::io::{self, Write};
+use std::str;
+#[cfg(feature = "terminal-io")]
+use terminal_io::{Terminal, TerminalColorSupport, WriteTerminal};
 use utf8_io::{Utf8Writer, WriteStr};
 #[cfg(not(windows))]
 use {
+    io_extras::os::rustix::{AsRawFd, RawFd},
     io_lifetimes::{AsFd, BorrowedFd},
-    unsafe_io::os::posish::{AsRawFd, RawFd},
 };
 
 /// A `WriteLayered` implementation which translates to an output
@@ -65,9 +64,9 @@ impl<Inner: Write> TextWriter<Utf8Writer<LayeredWriter<Inner>>> {
     /// "\r\n" for compatibility with consumers that need that.
     ///
     /// Note: This is not often needed; even on Windows these days most
-    /// things are ok with plain '\n' line endings, [including Windows Notepad].
-    /// The main notable things that really need them are IETF RFCs, for example
-    /// [RFC-5198].
+    /// things are ok with plain '\n' line endings, [including Windows
+    /// Notepad]. The main notable things that really need them are IETF
+    /// RFCs, for example [RFC-5198].
     ///
     /// [including Windows Notepad]: https://devblogs.microsoft.com/commandline/extended-eol-in-notepad/
     /// [RFC-5198]: https://tools.ietf.org/html/rfc5198#appendix-C
@@ -89,22 +88,22 @@ impl<Inner: WriteStr + WriteLayered> TextWriter<Inner> {
         }
     }
 
-    /// Like `from_utf8`, but writes a U+FEFF (BOM) to the beginning of the output
-    /// stream for compatibility with consumers that require that to determine
-    /// the text encoding.
+    /// Like `from_utf8`, but writes a U+FEFF (BOM) to the beginning of the
+    /// output stream for compatibility with consumers that require that to
+    /// determine the text encoding.
     #[inline]
     pub fn from_utf8_with_bom_compatibility(mut inner: Inner) -> io::Result<Self> {
         let output = TextOutput::with_bom_compatibility(&mut inner)?;
         Ok(Self { inner, output })
     }
 
-    /// Like `from_utf8`, but enables CRLF output mode, which translates "\n" to
-    /// "\r\n" for compatibility with consumers that need that.
+    /// Like `from_utf8`, but enables CRLF output mode, which translates "\n"
+    /// to "\r\n" for compatibility with consumers that need that.
     ///
     /// Note: This is not often needed; even on Windows these days most
-    /// things are ok with plain '\n' line endings, [including Windows Notepad].
-    /// The main notable things that really need them are IETF RFCs, for example
-    /// [RFC-5198].
+    /// things are ok with plain '\n' line endings, [including Windows
+    /// Notepad]. The main notable things that really need them are IETF
+    /// RFCs, for example [RFC-5198].
     ///
     /// [including Windows Notepad]: https://devblogs.microsoft.com/commandline/extended-eol-in-notepad/
     /// [RFC-5198]: https://tools.ietf.org/html/rfc5198#appendix-C
